@@ -5,11 +5,10 @@ from sql.aggregate import Min, Sum
 from sql.functions import CurrentTimestamp
 
 from trytond.model import ModelSQL, ModelView, fields
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval, Bool
-from trytond.transaction import Transaction
-
 from trytond.modules.currency.fields import Monetary
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Bool, Eval
+from trytond.transaction import Transaction
 
 
 class TaxTemplate(metaclass=PoolMeta):
@@ -31,8 +30,7 @@ class Tax(metaclass=PoolMeta):
         states={
             'readonly': (Bool(Eval('template', -1))
                 & ~Eval('template_override', False)),
-            },
-        depends=['template', 'template_override'])
+            })
 
 
 class ECSalesList(ModelSQL, ModelView):
@@ -118,14 +116,12 @@ class ECSalesListContext(ModelView):
         'account.fiscalyear', "Fiscal Year", required=True,
         domain=[
             ('company', '=', Eval('company')),
-            ],
-        depends=['company'])
+            ])
     period = fields.Many2One(
         'account.period', "Period",
         domain=[
             ('fiscalyear', '=', Eval('fiscalyear')),
-            ],
-        depends=['fiscalyear'])
+            ])
 
     @classmethod
     def default_company(cls):
